@@ -1,11 +1,4 @@
-# -*- coding: utf-8 -*-
-
 from .base import BatchOperator
-
 from .common import *
-
-from .connectors import *
-
-from .special_operators import *
-
 from .operator_with_methods import *
+from .special_operators import *
