@@ -6,7 +6,7 @@ from ..common.types.bases.params import Params
 from ..common.types.conversion.java_method_call import auto_convert_java_type
 from ..common.types.conversion.type_converters import py_list_to_j_array, dataframeToOperator, \
     lazy_collect_to_dataframes, collectToDataframes, j_value_to_py_value
-from ..common.utils.packages import in_ipython
+from ..common.utils.printing import print_with_title
 from ..py4j_util import get_java_class
 from ..udf.utils import register_pyflink_function
 
@@ -101,15 +101,9 @@ class BatchOperator(BaseOperator):
         register_pyflink_function(name, func, 'batch')
 
     def lazyPrint(self, n: int, title: str = None):
-        if in_ipython():
-            from IPython import display
-            print_fn = display.display
-        else:
-            print_fn = print
-
         from .common import FirstNBatchOp
         op = self.linkTo(FirstNBatchOp().setSize(n)) if n > 0 else self
-        op.lazyCollectToDataframe(lambda df: print_fn(df) if title is None else print_fn(title, df, sep="\n"))
+        op.lazyCollectToDataframe(lambda df: print_with_title(df, title))
         return self
 
     def lazyCollectToDataframe(self, *callbacks):
@@ -130,8 +124,7 @@ class BatchOperator(BaseOperator):
         return self
 
     def lazyPrintStatistics(self, title: str = None):
-        return self.lazyCollectStatistics(
-            lambda summary: print(summary) if title is None else print(title, summary, sep="\n"))
+        return self.lazyCollectStatistics(lambda summary: print_with_title(summary, title))
 
 
 class BaseSourceBatchOp(BatchOperator):
