@@ -20,13 +20,12 @@ def _get_default_local_ip():
 
 
 _env_variables = [
-    ("debug_mode", "ENABLE_DEBUG_MODE", False, bool),
+    ("debug_mode", "ENABLE_DEBUG_MODE", True, bool),
     ("flink_home", "FLINK_HOME", get_pyflink_path()),
     ("alink_deps_dir", "ALINK_DEPS_DIR", get_alink_lib_path()),
     ("alink_plugins_dir", "ALINK_PLUGINS_DIR", get_alink_plugins_path()),
     ("local_ip", "LOCAL_IP", _get_default_local_ip()),
     ("gateway_port", "PYALINK_GATEWAY_PORT", None),
-    ("java_opts_str", "PYALINK_JAVA_OPTS", None)
 ]
 
 g_config = {}
@@ -37,8 +36,6 @@ for entry in _env_variables:
         env_v = entry[3](env_v)
     g_config[entry[0]] = env_v
 
-g_config['java_opts'] = g_config['java_opts_str'].split() if g_config['java_opts_str'] is not None else []
-
 
 class AlinkGlobalConfiguration:
 
@@ -47,6 +44,22 @@ class AlinkGlobalConfiguration:
         _j_alink_global_configuration = get_java_class("com.alibaba.alink.common.AlinkGlobalConfiguration")
         return _j_alink_global_configuration
 
+    @classmethod
+    def isBatchPredictMultiThread(cls):
+        return cls._get_cls().isBatchPredictMultiThread()
+
+    @classmethod
+    def setBatchPredictMultiThread(cls, batchPredictMultiThread):
+        return cls._get_cls().setBatchPredictMultiThread(batchPredictMultiThread)
+
+    @classmethod
+    def isStreamPredictMultiThread(cls):
+        return cls._get_cls().isStreamPredictMultiThread()
+
+    @classmethod
+    def setStreamPredictMultiThread(cls, streamPredictMultiThread):
+        return cls._get_cls().setStreamPredictMultiThread(streamPredictMultiThread)
+
     @classmethod
     def isPrintProcessInfo(cls):
         return cls._get_cls().isPrintProcessInfo()
