@@ -1,3 +1,4 @@
+from ...common.utils.printing import print_with_title
 from ...batch.lazy.lazy_evaluation import PipeLazyEvaluationConsumer, LazyEvaluation
 from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
 from ...common.types.conversion.type_converters import j_value_to_py_value
@@ -5,14 +6,14 @@ from ...py4j_util import get_java_class
 
 
 class HasLazyPrintTrainInfo(JavaObjectWrapper):
-    def enableLazyPrintTrainInfo(self, title):
+    def enableLazyPrintTrainInfo(self, title=None):
         self.get_j_obj().enableLazyPrintTrainInfo(title)
 
         j_pipeline_lazy_printer_cls = get_java_class("com.alibaba.alink.common.lazy.PipelineLazyCallbackUtils")
 
         j_lazy_train_info = LazyEvaluation()
         py_lazy_train_info = j_lazy_train_info.transform(j_value_to_py_value)
-        py_lazy_train_info.addCallback(lambda d: print(title, d, sep="\n") if title is not None else print(d))
+        py_lazy_train_info.addCallback(lambda d: print_with_title(d, title))
 
         j_consumer = PipeLazyEvaluationConsumer(j_lazy_train_info)
 
