@@ -6,6 +6,11 @@ from ..common.utils.packages import is_flink_1_9
 from ..py4j_util import get_java_class
 
 
+def _to_dill_base64(v):
+    import dill
+    return ensure_unicode(base64.b64encode(dill.dumps(v, recurse=True)))
+
+
 def _to_cloudpickle_base64(v):
     import cloudpickle
     return ensure_unicode(base64.b64encode(cloudpickle.dumps(v)))
@@ -38,12 +43,12 @@ def _java_register_function(name, j_func, env_type):
 
 def register_pyflink_function(name, func, env_type):
     if not is_flink_1_9():
-        from pyflink.table.udf import UserDefinedFunctionWrapper
+        from pyflink.table.udf import UserDefinedScalarFunctionWrapper, UserDefinedTableFunctionWrapper
     else:
-        from .udf import UserDefinedFunctionWrapper
-    from .udtf import UserDefinedTableFunctionWrapper
+        from .udf import UserDefinedScalarFunctionWrapper
+        from .udtf import UserDefinedTableFunctionWrapper
 
-    if isinstance(func, UserDefinedFunctionWrapper):
+    if isinstance(func, UserDefinedScalarFunctionWrapper):
         result_type = _to_flink_type_string(func._result_type)
         j_func = _to_judf(name, func._func, result_type, 'CLOUDPICKLE_BASE64')
     elif isinstance(func, UserDefinedTableFunctionWrapper):
@@ -54,11 +59,13 @@ def register_pyflink_function(name, func, env_type):
     _java_register_function(name, j_func, env_type)
 
 
-def _to_judf(name, func, result_type, class_object_type):
+def _to_judf(name, func, result_type, class_object_type="DILL_BASE64"):
     if not callable(func) and not hasattr(func, "eval"):
         raise ValueError("Invalid function: not a callable or an object with attr eval")
 
-    if class_object_type == "CLOUDPICKLE_BASE64":
+    if class_object_type == "DILL_BASE64":
+        class_object = _to_dill_base64(func)
+    elif class_object_type == "CLOUDPICKLE_BASE64":
         class_object = _to_cloudpickle_base64(func)
     else:
         raise NotImplementedError
@@ -72,11 +79,13 @@ def _to_judf(name, func, result_type, class_object_type):
     return j_python_udf_factory_cls.makeScalarFunction(name, result_type, config_json)
 
 
-def _to_judtf(name, func, result_types, class_object_type):
+def _to_judtf(name, func, result_types, class_object_type="DILL_BASE64"):
     if not callable(func) and not hasattr(func, "eval"):
         raise ValueError("Invalid function: not a callable or an object with attr eval")
 
-    if class_object_type == "CLOUDPICKLE_BASE64":
+    if class_object_type == "DILL_BASE64":
+        class_object = _to_dill_base64(func)
+    elif class_object_type == "CLOUDPICKLE_BASE64":
         class_object = _to_cloudpickle_base64(func)
     else:
         raise NotImplementedError
@@ -99,10 +108,10 @@ def do_set_op_udf(op, func):
         return op
 
     if not is_flink_1_9():
-        from pyflink.table.udf import UserDefinedFunctionWrapper
+        from pyflink.table.udf import UserDefinedScalarFunctionWrapper
     else:
-        from .udf import UserDefinedFunctionWrapper
-    if isinstance(func, UserDefinedFunctionWrapper):
+        from .udf import UserDefinedScalarFunctionWrapper
+    if isinstance(func, UserDefinedScalarFunctionWrapper):
         result_type = _to_flink_type_string(func._result_type)
         op.setResultType(result_type) \
             .setClassObject(_to_cloudpickle_base64(func._func)) \
@@ -117,7 +126,10 @@ def do_set_op_udtf(op, func):
         op.setClassObjectType("CLOUDPICKLE_BASE64")
         return op
 
-    from .udtf import UserDefinedTableFunctionWrapper
+    if not is_flink_1_9():
+        from pyflink.table.udf import UserDefinedTableFunctionWrapper
+    else:
+        from .udtf import UserDefinedTableFunctionWrapper
     if isinstance(func, UserDefinedTableFunctionWrapper):
         result_types = list(map(_to_flink_type_string, func._result_types))
         op.setResultTypes(result_types) \
